/* A Bison parser, made by GNU Bison 3.0.2.  */

/* Bison interface for Yacc-like parsers in C

   Copyright (C) 1984, 1989-1990, 2000-2013 Free Software Foundation, Inc.

   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.  */

/* As a special exception, you may create a larger work that contains
   part or all of the Bison parser skeleton and distribute that work
   under terms of your choice, so long as that work isn't itself a
   parser generator using the skeleton or a modified version thereof
   as a parser skeleton.  Alternatively, if you modify or redistribute
   the parser skeleton itself, you may (at your option) remove this
   special exception, which will cause the skeleton and the resulting
   Bison output files to be licensed under the GNU General Public
   License without this special exception.

   This special exception was added by the Free Software Foundation in
   version 2.2 of Bison.  */

#ifndef YY_EXTR_PARSER_EXTRACTFILE_TAB_H_INCLUDED
# define YY_EXTR_PARSER_EXTRACTFILE_TAB_H_INCLUDED
/* Debug traces.  */
#ifndef EXTR_DEBUG
# if defined YYDEBUG
#if YYDEBUG
#   define EXTR_DEBUG 1
#  else
#   define EXTR_DEBUG 0
#  endif
# else /* ! defined YYDEBUG */
#  define EXTR_DEBUG 1
# endif /* ! defined YYDEBUG */
#endif  /* ! defined EXTR_DEBUG */
#if EXTR_DEBUG
extern int extr_debug;
#endif

/* Token type.  */
#ifndef EXTR_TOKENTYPE
# define EXTR_TOKENTYPE
  enum extr_tokentype
  {
    extrERROR = 258,
    extrOPEN = 259,
    extrCLOSE = 260,
    extrTYPE = 261,
    extrIMPLIES = 262,
    extrAS = 263,
    extrHASH = 264,
    extrCOLON = 265,
    extrSIZE = 266,
    extrCOMMA = 267,
    extrSTRING = 268
  };
#endif
/* Tokens.  */
#define extrERROR 258
#define extrOPEN 259
#define extrCLOSE 260
#define extrTYPE 261
#define extrIMPLIES 262
#define extrAS 263
#define extrHASH 264
#define extrCOLON 265
#define extrSIZE 266
#define extrCOMMA 267
#define extrSTRING 268

/* Value type.  */
#if ! defined EXTR_STYPE && ! defined EXTR_STYPE_IS_DECLARED
typedef union EXTR_STYPE EXTR_STYPE;
union EXTR_STYPE
{
#line 61 "parser/extractFile.y" /* yacc.c:1909  */

  off_t  size;
  char   string[MAX_SIZE_STRING+1];
  char   hash[MAX_SIZE_MD5+1];
  EType  type; 
  Archive* archive;

#line 96 "parser/extractFile.tab.h" /* yacc.c:1909  */
};
# define EXTR_STYPE_IS_TRIVIAL 1
# define EXTR_STYPE_IS_DECLARED 1
#endif



int extr_parse (yyscan_t yyscanner, Collection* coll, Container* container);
/* "%code provides" blocks.  */
#line 27 "parser/extractFile.y" /* yacc.c:1909  */

/*=======================================================================
 * Version: this file is generated by BISON using extractFile.y
 * Project: MediaTeX
 * Module : extraction meta-date parser
 *
 * extract parser.

 MediaTex is an Electronic Records Management System
 Copyright (C) 2014 2015 Nicolas Roche
   
 This program is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation, either version 3 of the License, or
 any later version.
   
 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.
   
 You should have received a copy of the GNU General Public License
 along with this program.  If not, see <http://www.gnu.org/licenses/>.
 =======================================================================*/

#define YYSTYPE EXTR_STYPE

#line 134 "parser/extractFile.tab.h" /* yacc.c:1909  */

#endif /* !YY_EXTR_PARSER_EXTRACTFILE_TAB_H_INCLUDED  */
